window.Gleam.initSearch([{"doc":"systemd_status","title":"systemd_status","content":"# systemd_status\n\nInspect the status of running systemd units.\n\n[![Package Version](https://img.shields.io/hexpm/v/systemd_status)](https://hex.pm/packages/systemd_status)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/systemd_status/)\n\n```sh\ngleam add systemd_status\n```\n```gleam\nimport systemd_status\n\n// In this example we&#39;re also using the shellout package\nimport shellout\n\npub fn main() {\n  let #(command, arguments) = systemd_status.unit_property_list_command(&quot;my-service&quot;)\n  let assert Ok(output) = shellout.command(command, arguments, in: &quot;.&quot;, opt: [])\n  let assert Ok(service) = systemd_status.parse_service(output)\n  service\n  // Service(\n  //   id: &quot;my-service.service&quot;,\n  //   type_: SimpleService,\n  //   load_state: Loaded,\n  //   active_state: Active,\n  //   sub_state: &quot;running&quot;,\n  //   result: &quot;success&quot;,\n  //   main_pid: Some(3_764_255),\n  //   description: Some(&quot;Super cool important service&quot;),\n  //   state_change_timestamp: Some(&quot;Tue 2024-02-27 22:50:37 UTC&quot;),\n  //   active_enter_timestamp: Some(&quot;Tue 2024-02-27 22:50:37 UTC&quot;),\n  //   active_exit_timestamp: Some(&quot;Tue 2024-02-27 22:50:37 UTC&quot;),\n  //   inactive_enter_timestamp: Some(&quot;Tue 2024-02-27 22:50:37 UTC&quot;),\n  //   inactive_exit_timestamp: Some(&quot;Tue 2024-02-27 22:50:37 UTC&quot;),\n  // )\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/systemd_status&gt;.\n","url":"index.html"},{"doc":"systemd_status","title":"ActiveState","content":"pub type ActiveState {\n  Active\n  Reloading\n  Inactive\n  Failed\n  Activating\n  Deactivating\n}\n\nActive\n\n\nReloading\n\n\nInactive\n\n\nFailed\n\n\nActivating\n\n\nDeactivating\n\n\nSynonyms:\nsystemd_status.ActiveState\nsystemd_status ActiveState","url":"systemd_status.html#ActiveState"},{"doc":"systemd_status","title":"LoadState","content":"pub type LoadState {\n  Loaded\n  NotFound\n  BadSetting\n  LoadError\n  Masked\n}\n\nLoaded\n\n\nNotFound\n\n\nBadSetting\n\n\nLoadError\n\n\nMasked\n\n\nSynonyms:\nsystemd_status.LoadState\nsystemd_status LoadState","url":"systemd_status.html#LoadState"},{"doc":"systemd_status","title":"Service","content":"pub type Service {\n  Service(\n    id: String,\n    type_: ServiceType,\n    load_state: LoadState,\n    active_state: ActiveState,\n    sub_state: String,\n    result: String,\n    description: Option(String),\n    main_pid: Option(Int),\n    state_change_timestamp: Option(String),\n    active_enter_timestamp: Option(String),\n    active_exit_timestamp: Option(String),\n    inactive_enter_timestamp: Option(String),\n    inactive_exit_timestamp: Option(String),\n  )\n}\n A service type unit.\nService(\n  id: String,\n  type_: ServiceType,\n  load_state: LoadState,\n  active_state: ActiveState,\n  sub_state: String,\n  result: String,\n  description: Option(String),\n  main_pid: Option(Int),\n  state_change_timestamp: Option(String),\n  active_enter_timestamp: Option(String),\n  active_exit_timestamp: Option(String),\n  inactive_enter_timestamp: Option(String),\n  inactive_exit_timestamp: Option(String),\n)\n\n\nSynonyms:\nsystemd_status.Service\nsystemd_status Service","url":"systemd_status.html#Service"},{"doc":"systemd_status","title":"ServiceType","content":"pub type ServiceType {\n  SimpleService\n  OneshotService\n  OtherServiceType(name: String)\n}\n\nSimpleService\n\n\nOneshotService\n\n\nOtherServiceType(name: String)\n\n\nSynonyms:\nsystemd_status.ServiceType\nsystemd_status ServiceType","url":"systemd_status.html#ServiceType"},{"doc":"systemd_status","title":"parse_service","content":"pub fn parse_service(input: String) -&gt; Result(Service, String)\n Parse a property list for a service unit into a `Service`.\n\n The property list can be fetched by running the command returned by the\n `unit_property_list_command` function.\n\n If the property list is not for a service unit then it will fail to parse.\n\n If the property list is for multiple units (that is, if it contains a\n double newline) only the first unit will be parsed.\n\nSynonyms:\nsystemd_status.parse_service\nsystemd_status parse_service","url":"systemd_status.html#parse_service"},{"doc":"systemd_status","title":"unit_property_list_command","content":"pub fn unit_property_list_command(\n  unit: String,\n) -&gt; #(String, List(String))\n A command you can run to get the information needed by this library about a\n unit to be able to parse it using `parse_service`.\n\n Wildcards can be used in the unit name to get information about multiple\n units. In this case the properties for each unit will be separated by two\n newlines (`&quot;\\n\\n&quot;`).\n\n # Security\n\n This command runs `systemctl`. On a machine with systemd installed this is\n safe, however if the executable `systemctl` has not been provided by systemd\n then this unknown executable will be run with the provided arguments, which\n could be harmful. Do not run commands unless you are confident it is safe to\n do so.\n\nSynonyms:\nsystemd_status.unit_property_list_command\nsystemd_status unit_property_list_command","url":"systemd_status.html#unit_property_list_command"},{"doc":"systemd_status","title":"systemd_status","content":"","url":"systemd_status.html"}]);